@@ -1190,281 +1190,6 @@ impl ContractListBuilder {
     }
 }
 
-/// Native implementation for SmartPermission
-#[derive(Default, Debug, Clone, PartialEq)]
-pub struct SmartPermission {
-    name: String,
-    org_id: String,
-    function: Vec<u8>,
-}
-
-impl SmartPermission {
-    pub fn name(&self) -> &String {
-        &self.name
-    }
-
-    pub fn org_id(&self) -> &String {
-        &self.org_id
-    }
-
-    pub fn function(&self) -> &[u8] {
-        &self.function
-    }
-
-    pub fn into_builder(self) -> SmartPermissionBuilder {
-        SmartPermissionBuilder::new()
-            .with_name(self.name)
-            .with_org_id(self.org_id)
-            .with_function(self.function)
-    }
-}
-
-impl FromProto<protos::smart_permission::SmartPermission> for SmartPermission {
-    fn from_proto(
-        proto: protos::smart_permission::SmartPermission,
-    ) -> Result<Self, ProtoConversionError> {
-        Ok(SmartPermission {
-            name: proto.get_name().to_string(),
-            org_id: proto.get_org_id().to_string(),
-            function: proto.get_function().to_vec(),
-        })
-    }
-}
-
-impl FromNative<SmartPermission> for protos::smart_permission::SmartPermission {
-    fn from_native(smart_permission: SmartPermission) -> Result<Self, ProtoConversionError> {
-        let mut proto = protos::smart_permission::SmartPermission::new();
-
-        proto.set_name(smart_permission.name().to_string());
-        proto.set_org_id(smart_permission.org_id().to_string());
-        proto.set_function(smart_permission.function().to_vec());
-
-        Ok(proto)
-    }
-}
-
-impl FromBytes<SmartPermission> for SmartPermission {
-    fn from_bytes(bytes: &[u8]) -> Result<SmartPermission, ProtoConversionError> {
-        let proto: protos::smart_permission::SmartPermission = Message::parse_from_bytes(bytes)
-            .map_err(|_| {
-                ProtoConversionError::SerializationError(
-                    "Unable to get SmartPermission from bytes".to_string(),
-                )
-            })?;
-        proto.into_native()
-    }
-}
-
-impl IntoBytes for SmartPermission {
-    fn into_bytes(self) -> Result<Vec<u8>, ProtoConversionError> {
-        let proto = self.into_proto()?;
-        let bytes = proto.write_to_bytes().map_err(|_| {
-            ProtoConversionError::SerializationError(
-                "Unable to get bytes from SmartPermission".to_string(),
-            )
-        })?;
-        Ok(bytes)
-    }
-}
-
-impl IntoProto<protos::smart_permission::SmartPermission> for SmartPermission {}
-impl IntoNative<SmartPermission> for protos::smart_permission::SmartPermission {}
-
-#[derive(Debug)]
-pub enum SmartPermissionBuildError {
-    MissingField(String),
-}
-
-impl StdError for SmartPermissionBuildError {
-    fn description(&self) -> &str {
-        match *self {
-            SmartPermissionBuildError::MissingField(ref msg) => msg,
-        }
-    }
-}
-
-impl std::fmt::Display for SmartPermissionBuildError {
-    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
-        match *self {
-            SmartPermissionBuildError::MissingField(ref s) => write!(f, "MissingField: {}", s),
-        }
-    }
-}
-
-/// Builder used to create a SmartPermission
-#[derive(Default, Clone)]
-pub struct SmartPermissionBuilder {
-    name: Option<String>,
-    org_id: Option<String>,
-    function: Vec<u8>,
-}
-
-impl SmartPermissionBuilder {
-    pub fn new() -> Self {
-        SmartPermissionBuilder::default()
-    }
-
-    pub fn with_name(mut self, name: String) -> SmartPermissionBuilder {
-        self.name = Some(name);
-        self
-    }
-
-    pub fn with_org_id(mut self, org_id: String) -> SmartPermissionBuilder {
-        self.org_id = Some(org_id);
-        self
-    }
-
-    pub fn with_function(mut self, function: Vec<u8>) -> SmartPermissionBuilder {
-        self.function = function;
-        self
-    }
-
-    pub fn build(self) -> Result<SmartPermission, SmartPermissionBuildError> {
-        let name = self.name.ok_or_else(|| {
-            SmartPermissionBuildError::MissingField("'name' field is required".to_string())
-        })?;
-
-        let org_id = self.org_id.ok_or_else(|| {
-            SmartPermissionBuildError::MissingField("'org_id' field is required".to_string())
-        })?;
-
-        let function = {
-            if !self.function.is_empty() {
-                self.function
-            } else {
-                return Err(SmartPermissionBuildError::MissingField(
-                    "'function' field is required".to_string(),
-                ));
-            }
-        };
-
-        Ok(SmartPermission {
-            name,
-            org_id,
-            function,
-        })
-    }
-}
-
-// Native implementation for SmartPermissionList
-#[derive(Default, Debug, Clone, PartialEq)]
-pub struct SmartPermissionList {
-    smart_permissions: Vec<SmartPermission>,
-}
-
-impl SmartPermissionList {
-    pub fn smart_permissions(&self) -> &[SmartPermission] {
-        &self.smart_permissions
-    }
-}
-
-impl FromProto<protos::smart_permission::SmartPermissionList> for SmartPermissionList {
-    fn from_proto(
-        proto: protos::smart_permission::SmartPermissionList,
-    ) -> Result<Self, ProtoConversionError> {
-        Ok(SmartPermissionList {
-            smart_permissions: proto
-                .get_smart_permissions()
-                .to_vec()
-                .into_iter()
-                .map(SmartPermission::from_proto)
-                .collect::<Result<Vec<SmartPermission>, ProtoConversionError>>()?,
-        })
-    }
-}
-
-impl FromNative<SmartPermissionList> for protos::smart_permission::SmartPermissionList {
-    fn from_native(
-        smart_permissions_list: SmartPermissionList,
-    ) -> Result<Self, ProtoConversionError> {
-        let mut proto = protos::smart_permission::SmartPermissionList::new();
-        proto.set_smart_permissions(RepeatedField::from_vec(
-            smart_permissions_list
-                .smart_permissions()
-                .to_vec()
-                .into_iter()
-                .map(SmartPermission::into_proto)
-                .collect::<Result<Vec<protos::smart_permission::SmartPermission>, ProtoConversionError>>()?,
-        ));
-
-        Ok(proto)
-    }
-}
-
-impl FromBytes<SmartPermissionList> for SmartPermissionList {
-    fn from_bytes(bytes: &[u8]) -> Result<SmartPermissionList, ProtoConversionError> {
-        let proto: protos::smart_permission::SmartPermissionList = Message::parse_from_bytes(bytes)
-            .map_err(|_| {
-                ProtoConversionError::SerializationError(
-                    "Unable to get SmartPermissionList from bytes".to_string(),
-                )
-            })?;
-        proto.into_native()
-    }
-}
-
-impl IntoBytes for SmartPermissionList {
-    fn into_bytes(self) -> Result<Vec<u8>, ProtoConversionError> {
-        let proto = self.into_proto()?;
-        let bytes = proto.write_to_bytes().map_err(|_| {
-            ProtoConversionError::SerializationError(
-                "Unable to get bytes from SmartPermissionList".to_string(),
-            )
-        })?;
-        Ok(bytes)
-    }
-}
-
-impl IntoProto<protos::smart_permission::SmartPermissionList> for SmartPermissionList {}
-impl IntoNative<SmartPermissionList> for protos::smart_permission::SmartPermissionList {}
-
-#[derive(Debug)]
-pub enum SmartPermissionListBuildError {
-    MissingField(String),
-}
-
-impl StdError for SmartPermissionListBuildError {
-    fn description(&self) -> &str {
-        match *self {
-            SmartPermissionListBuildError::MissingField(ref msg) => msg,
-        }
-    }
-}
-
-impl std::fmt::Display for SmartPermissionListBuildError {
-    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
-        match *self {
-            SmartPermissionListBuildError::MissingField(ref s) => write!(f, "MissingField: {}", s),
-        }
-    }
-}
-
-/// Builder used to create a SmartPermissionList
-#[derive(Default, Clone)]
-pub struct SmartPermissionListBuilder {
-    smart_permissions: Vec<SmartPermission>,
-}
-
-impl SmartPermissionListBuilder {
-    pub fn new() -> Self {
-        SmartPermissionListBuilder::default()
-    }
-
-    pub fn with_smart_permissions(
-        mut self,
-        smart_permissions: Vec<SmartPermission>,
-    ) -> SmartPermissionListBuilder {
-        self.smart_permissions = smart_permissions;
-        self
-    }
-
-    pub fn build(self) -> Result<SmartPermissionList, SmartPermissionListBuildError> {
-        let smart_permissions = self.smart_permissions;
-
-        Ok(SmartPermissionList { smart_permissions })
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -1860,101 +1585,4 @@ mod tests {
         let contract_list = ContractList::from_bytes(&bytes).unwrap();
         assert_eq!(contract_list, original);
     }
-
-    #[test]
-    // check that a smart permission is built correctly
-    fn check_smart_permission() {
-        let builder = SmartPermissionBuilder::new();
-        let smart_permission = builder
-            .with_name("Tests".to_string())
-            .with_org_id("org_id".to_string())
-            .with_function(b"test_function".to_vec())
-            .build()
-            .unwrap();
-
-        assert_eq!(smart_permission.name(), "Tests");
-        assert_eq!(smart_permission.org_id(), "org_id");
-        assert_eq!(smart_permission.function(), b"test_function");
-    }
-
-    #[test]
-    // check that a smart permission can be converted to bytes and back
-    fn check_smart_permission_bytes() {
-        let builder = SmartPermissionBuilder::new();
-        let original = builder
-            .with_name("Tests".to_string())
-            .with_org_id("org_id".to_string())
-            .with_function(b"test_function".to_vec())
-            .build()
-            .unwrap();
-
-        let bytes = original.clone().into_bytes().unwrap();
-
-        let smart_permission = SmartPermission::from_bytes(&bytes).unwrap();
-        assert_eq!(smart_permission, original);
-    }
-
-    #[test]
-    // check that a smart permission can be converted to builder
-    fn check_smart_permission_into_builder() {
-        let builder = SmartPermissionBuilder::new();
-        let smart_permission = builder
-            .with_name("Tests".to_string())
-            .with_org_id("org_id".to_string())
-            .with_function(b"test_function".to_vec())
-            .build()
-            .unwrap();
-
-        let builder = smart_permission.into_builder();
-
-        assert_eq!(builder.name, Some("Tests".to_string()));
-        assert_eq!(builder.org_id, Some("org_id".to_string()));
-        assert_eq!(builder.function, b"test_function".to_vec());
-    }
-
-    #[test]
-    // check that a smart permission list is built correctly
-    fn check_smart_permission_list() {
-        let builder = SmartPermissionBuilder::new();
-        let smart_permission = builder
-            .with_name("Tests".to_string())
-            .with_org_id("org_id".to_string())
-            .with_function(b"test_function".to_vec())
-            .build()
-            .unwrap();
-
-        let builder = SmartPermissionListBuilder::new();
-        let smart_permission_list = builder
-            .with_smart_permissions(vec![smart_permission.clone()])
-            .build()
-            .unwrap();
-
-        assert_eq!(
-            smart_permission_list.smart_permissions(),
-            [smart_permission]
-        );
-    }
-
-    #[test]
-    // check that a smart permission list can be converted to bytes and back
-    fn check_smart_permission_list_bytes() {
-        let builder = SmartPermissionBuilder::new();
-        let smart_permission = builder
-            .with_name("Tests".to_string())
-            .with_org_id("org_id".to_string())
-            .with_function(b"test_function".to_vec())
-            .build()
-            .unwrap();
-
-        let builder = SmartPermissionListBuilder::new();
-        let original = builder
-            .with_smart_permissions(vec![smart_permission.clone()])
-            .build()
-            .unwrap();
-
-        let bytes = original.clone().into_bytes().unwrap();
-
-        let smart_permission_list = SmartPermissionList::from_bytes(&bytes).unwrap();
-        assert_eq!(smart_permission_list, original);
-    }
 }
